@@ -75,6 +75,10 @@ class CommonData
 	public static $NTPC_DIR = "/icpdas/ntpc";
 	public static $NTPC_EXE = "ntpc.php";
 	public static $NTPC_CONFIG = "/icpdas/ntpc/ntpc.ini";
+
+	//VPN Client
+	public static $VPNC_DIR = "/icpdas/vpnc";
+	public static $VPNC_EXE = "vpnc.php";
 }
 
 //== get or set interface information from "/etc/network/interfaces"
@@ -493,6 +497,30 @@ function getNetInfo(&$net_info)
 		$info = strstr($info, "Mask:");
 		strtok($info, ":");
 		$net_info["ppp0_mask"] = strtok("\n ");
+
+		//-- ppp1 --
+		$cmd = "ifconfig ppp1";
+		$info = shell_exec($cmd);
+		//-- get IP
+		$info = strstr($info, "inet addr:");
+		strtok($info, ":");
+		$net_info["ppp1_ip"] = strtok("\t ");
+
+		//-- get connect status
+		if($net_info["ppp1_ip"] == "")
+			$net_info["ppp1_conn"] = "not connect";
+		else
+			$net_info["ppp1_conn"] = "connected";
+
+		//-- get P-t-P (broad cast)
+		$info = strstr($info, "P-t-P:");
+		strtok($info, ":");
+		$net_info["ppp1_ptp"] = strtok("\t ");
+
+		//-- get Mask
+		$info = strstr($info, "Mask:");
+		strtok($info, ":");
+		$net_info["ppp1_mask"] = strtok("\n ");
 	}
 	catch (Exception $e)
 	{
@@ -1225,8 +1253,10 @@ function setGprsMonitorInfo($serverIP, $maxRetry, $interval, $timeout)
 //==== Reboot Timer manage ====
 //============================
 //== get information
-function getRebootTimerInfo(&$interval, &$enable, &$alive)
+function getRebootTimerInfo(&$rbHour, &$rbMinute, &$enable, &$alive, &$version)
 {
+	$rbHour = 0;
+	$rbMinute = 0;
 	$IsObject=false;
 	$data=file_get_contents(CommonData::$REBOOTT_CONFIG);
 	$array_data=explode("\n",$data);
@@ -1238,9 +1268,13 @@ function getRebootTimerInfo(&$interval, &$enable, &$alive)
 		if($line[0]=='#') continue;
 
 		list($name , $value)=split('=' , $line);
-		if($name == "interval")
+		if($name == "rbHour")
 		{
-			$interval = (int)$value;
+			$rbHour = (int)$value;
+		}
+		if($name == "rbMinute")
+		{
+			$rbMinute = (int)$value;
 		}
 	}
 
@@ -1258,13 +1292,19 @@ function getRebootTimerInfo(&$interval, &$enable, &$alive)
 			break;
 		}
 	}
+
+	//- get version
+	$version = shell_exec($full_file_name ." --ver");
+	$array_data = explode("=", $version);
+	$version = trim($array_data[1]);
 }
 
 //== set config
-function setRebootTimerInfo($interval)
+function setRebootTimerInfo($rbHour, $rbMinute)
 {
 	$data="";
-	$data = $data ."interval=" .$interval ."\n";
+	$data = $data ."rbHour=" .$rbHour ."\n";
+	$data = $data ."rbMinute=" .$rbMinute ."\n";
 	file_put_contents(CommonData::$REBOOTT_CONFIG, $data);
 }
 
@@ -1458,6 +1498,8 @@ function tarWebConfig()
 					."/icpdas/vxsc/vxserver.ini "
 					."/icpdas/rebootTimer/rebootTimer.ini "
 					."/icpdas/rtuc/rtuc.ini "
+					."/etc/udev/rules.d/* "
+					."/etc/localtime "
 ;
 
 	$cmd .= $exportFiles;
